import type { ChattyHostBuilder } from '@looker/chatty';
import type { CookielessCallback, GenerateTokensCallback, CookielessRequestInit, LookerAuthConfig, LookerEmbedCookielessSessionData, ILookerEmbedSDK, IEmbedBuilder } from './types';
/**
 * @hidden
 */
export declare type ChattyHostBuilderFactory = (url: string) => ChattyHostBuilder;
/**
 * @hidden
 */
export declare const createChattyBuilder: (url: string) => ChattyHostBuilder;
/**
 * @hidden
 */
export interface ICookielessEmbedSession {
    generateTokensTime: number;
    cookielessApiToken?: string | null;
    cookielessApiTokenTtl?: number | null;
    cookielessNavigationToken?: string | null;
    cookielessNavigationTokenTtl?: number | null;
    cookielessSessionReferenceTokenTtl?: number | null;
}
export declare class LookerEmbedExSDK implements ILookerEmbedSDK {
    private _chattyHostCreator;
    /**
     * @hidden
     */
    _sessionCreated: boolean;
    /**
     * @hidden
     */
    _createEmbedSessionPromise?: Promise<string>;
    /**
     * @hidden
     */
    _createEmbedSessionPromiseResolver?: (value: string | PromiseLike<string>) => void;
    /**
     * @hidden
     */
    _generateTokensPromise?: Promise<LookerEmbedCookielessSessionData>;
    /**
     * @hidden
     */
    _apiHost?: string;
    /**
     * @hidden
     */
    _auth?: LookerAuthConfig;
    /**
     * @hidden
     */
    _acquireSession?: string | CookielessRequestInit | CookielessCallback;
    /**
     * @hidden
     */
    _generateTokens?: string | CookielessRequestInit | GenerateTokensCallback;
    /**
     * @hidden
     */
    _cookielessSession?: ICookielessEmbedSession;
    /**
     * @hidden
     */
    constructor(_chattyHostCreator?: ChattyHostBuilderFactory);
    init(apiHost: string, auth?: string | LookerAuthConfig): void;
    initCookieless(apiHost: string, acquireSession: string | CookielessRequestInit | CookielessCallback, generateTokens: string | CookielessRequestInit | GenerateTokensCallback): void;
    clearSession(): void;
    preload(): IEmbedBuilder;
    createWithUrl(url: string): IEmbedBuilder;
    createDashboardWithUrl(url: string): IEmbedBuilder;
    createDashboardWithId(id: string | number): IEmbedBuilder;
    createExploreWithUrl(url: string): IEmbedBuilder;
    createExploreWithId(id: string): IEmbedBuilder;
    createMergeQueryWithUrl(url: string): IEmbedBuilder;
    createMergeQueryWithId(id: string): IEmbedBuilder;
    createQueryWithUrl(url: string): IEmbedBuilder;
    createQueryWithId(model: string, view: string, qid: string): IEmbedBuilder;
    createLookWithUrl(url: string): IEmbedBuilder;
    createLookWithId(id: number | string): IEmbedBuilder;
    createExtensionWithUrl(url: string): IEmbedBuilder;
    createExtensionWithId(id: string): IEmbedBuilder;
    createQueryVisualizationWithUrl(url: string): IEmbedBuilder;
    createQueryVisualizationWithId(id: string): IEmbedBuilder;
    createReportWithUrl(url: string): IEmbedBuilder;
    createReportWithId(id: string): IEmbedBuilder;
    /**
     * @hidden
     */
    get apiHost(): string;
    /**
     * @hidden
     */
    set apiHost(apiHost: string);
    /**
     * @hidden
     */
    get auth(): LookerAuthConfig;
    /**
     * @hidden
     */
    set auth(auth: LookerAuthConfig);
    /**
     * @hidden
     */
    get acquireSession(): string | CookielessRequestInit | CookielessCallback;
    /**
     * @hidden
     */
    get generateTokens(): string | CookielessRequestInit | GenerateTokensCallback;
    /**
     * @hidden
     */
    get chattyHostCreator(): ChattyHostBuilderFactory;
}
/**
 * Get the Embed SDK
 */
export declare const getEmbedSDK: (embedSdk?: LookerEmbedExSDK) => LookerEmbedExSDK;
