import type { LookerAuthConfig, CookielessCallback, CookielessRequestInit } from './types';
export * from './types';
export * from './LookerEmbedExSDK';
export * from './types';
/**
 * @deprecated Use <code>getEmbedSDK()</code> instead.
 */
export declare class LookerEmbedSDK {
    /**
     * Initialize the Embed SDK.
     *
     * @param apiHost The address or base URL of the Looker host (example.looker.com:9999, https://example.looker.com:9999)
     *                This is required for verification of messages sent from the embedded content.
     * @param authUrl A server endpoint that will sign SSO embed URLs
     *
     * @deprecated Use <code>getEmbedSDK().init(...)</code> instead.
     */
    static init(apiHost: string, auth?: string | LookerAuthConfig): void;
    /**
     * Initialize the Embed SDK to use a cookieless session.
     *
     * @param apiHost The address or base URL of the host (example.looker.com:9999, https://example.looker.com:9999)
     * @param acquireSession is either a string containing a server endpoint that will acquire the embed session OR
     * a RequestInfo object for a fetch call to the server endpoint that will acquire the embed session OR
     * a callback that will invoke the server endpoint that will acquire the embed session.
     * The server endpoint must ultimately call the Looker endpoint `acquire_embed_cookieless_session`.
     * @param generateTokens is either a string containing a server endpoint that will generate new tokens OR
     * a RequestInfo object for a fetch call to the server endpoint that will generate new tokens OR
     * a callback that will invoke the server endpoint that will generate new tokens.
     * The server endpoint should ultimately call the Looker endpoint `generate_tokens_for_cookieless_session`.
     *
     * Looker 22.20+
     *
     * @deprecated Use <code>getEmbedSDK().initCookieless(...)</code> instead.
     */
    static initCookieless(apiHost: string, acquireSession: string | CookielessRequestInit | CookielessCallback, generateTokens: string | CookielessRequestInit | CookielessCallback): void;
    /**
     * Create an EmbedBuilder for an embedded Looker dashboard.
     *
     * @param url A signed SSO embed URL or embed URL for an already authenticated Looker user
     *
     * @deprecated Use <code>getEmbedSDK().createDashboardWithUrl(...)</code> instead.
     */
    static createDashboardWithUrl(url: string): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker dashboard.
     *
     * @param id The numeric ID of a Looker User Defined Dashboard, or LookML Dashboard ID
     *
     * @deprecated Use <code>getEmbedSDK().createDashboardWithId(...)</code> instead.
     */
    static createDashboardWithId(id: string | number): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker Explore.
     *
     * @param url A signed SSO embed URL or embed URL for an already authenticated Looker user
     *
     * @deprecated Use <code>getEmbedSDK().createExploreWithUrl(...)</code> instead.
     */
    static createExploreWithUrl(url: string): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker Explore.
     *
     * @param id The ID of a Looker explore
     *
     * @deprecated Use <code>getEmbedSDK().createExploreWithId(...)</code> instead.
     */
    static createExploreWithId(id: string): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker Look.
     *
     * @param url A signed SSO embed URL or embed URL for an already authenticated Looker user
     *
     * @deprecated Use <code>getEmbedSDK().createLookWithUrl(...)</code> instead.
     */
    static createLookWithUrl(url: string): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker dashboard.
     *
     * @param id The ID of a Looker Look
     *
     * @deprecated Use <code>getEmbedSDK().createLookWithId(...)</code> instead.
     */
    static createLookWithId(id: number): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker extension.
     *
     * @param url A signed SSO embed URL or embed URL for an already authenticated Looker user
     *
     * @deprecated Use <code>getEmbedSDK().createExtensionWithUrl(...)</code> instead.
     */
    static createExtensionWithUrl(url: string): import("./types").IEmbedBuilder;
    /**
     * Create an EmbedBuilder for an embedded Looker extension. Requires Looker 7.12
     *
     * @param id The ID of a Looker Look
     *
     * @deprecated Use <code>getEmbedSDK().createExtensionWithId(...)</code> instead.
     */
    static createExtensionWithId(id: string): import("./types").IEmbedBuilder;
}
